<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>and</source>
        <translation>a</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>Qt runtime version: </source>
        <translation>Běhová verze Qt: </translation>
    </message>
    <message>
        <source>Danish</source>
        <translation>Dánština</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francouzština</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Němčina</translation>
    </message>
    <message>
        <source>This is the qStopMotion application for creating stop motion animations.</source>
        <translation>Toto je program qStopMotion, který je určen k vytváření animovaných filmů dělaných technikou pookénkové nebo také fázové animace.</translation>
    </message>
    <message>
        <source>qStopMotion is a fork of stopmotion for linux.</source>
        <translation>qStopMotion vznikl odvozením z programu stopmotion pro Linux.</translation>
    </message>
    <message>
        <source>&amp;Thanks To</source>
        <translation>&amp;Poděkování</translation>
    </message>
    <message>
        <source>&amp;System Info</source>
        <translation>&amp;Systém</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Verze: </translation>
    </message>
    <message>
        <source>Build time: %1 %2</source>
        <translation>Čas sestavení: %1 %2</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Překlad</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation>Švédština</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>Přispěvatelé</translation>
    </message>
    <message>
        <source>Operating system name and version: </source>
        <translation>Název a verze operačního systému: </translation>
    </message>
    <message>
        <source>Main developers</source>
        <translation>Hlavní vývojáři</translation>
    </message>
    <message>
        <source>This program is distributed under the terms of the GPL v2.</source>
        <translation>Tento program je šířen za podmínek licence GPL v2.</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation>&amp;Autoři</translation>
    </message>
    <message>
        <source>&amp;Licence Agreement</source>
        <translation>&amp;Povolení</translation>
    </message>
    <message>
        <source>Unknown Windows OS</source>
        <translation>Neznámé Windows OS</translation>
    </message>
    <message>
        <source>Unknown Mac OS</source>
        <translation>Neznámé Mac OS</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>Čeština</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AnimationProject</name>
    <message>
        <source>Cannot open the selected audio file for reading.
Check that you have the right permissions set.
The animation will be run without sound if you
choose to play.</source>
        <translation>Vybraný soubor se záznamem zvuku nelze otevřít pro čtení.
Prověřte, že jsou oprávnění nastavena správně.
Animace bude, v případě že se rozhodnete pro přehrání,
přehrána bez zvuku.</translation>
    </message>
    <message>
        <source>The selected audio file is not valid within the
given audio format. The animation will be run
without sound if you choose to play.</source>
        <translation>Vybraný soubor se záznamem zvuku není v platném
zvukovém formátu. Animace bude, v případě že se
rozhodnete pro přehrání, přehrána bez zvuku.</translation>
    </message>
    <message>
        <source>Add Sound</source>
        <translation>Přidat zvuk</translation>
    </message>
    <message>
        <source>Saving scenes to disk ...</source>
        <translation>Výjevy se ukládají na disk...</translation>
    </message>
</context>
<context>
    <name>CameraControllerDialog</name>
    <message>
        <source>Hue:</source>
        <translation>Odstín:</translation>
    </message>
    <message>
        <source>Pan:</source>
        <translation>Smyk:</translation>
    </message>
    <message>
        <source>Gain:</source>
        <translation>Zesílení:</translation>
    </message>
    <message>
        <source>Iris:</source>
        <translation>Stínítko:</translation>
    </message>
    <message>
        <source>Roll:</source>
        <translation>Točení:</translation>
    </message>
    <message>
        <source>Tilt:</source>
        <translation>Naklonění:</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation>Zvětšení:</translation>
    </message>
    <message>
        <source>Color Enable:</source>
        <translation>Povolení barvy:</translation>
    </message>
    <message>
        <source>Automatic Hue</source>
        <translation>Automatický barevný odstín</translation>
    </message>
    <message>
        <source>Automatic Pan</source>
        <translation>Automatický smyk (pohyb kamery)</translation>
    </message>
    <message>
        <source>Camera Control</source>
        <translation>Ovládání kamery</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Automatic Backlight Compensation</source>
        <translation>Automatické vyrovnání osvětlení zezadu</translation>
    </message>
    <message>
        <source>Automatic Exposure</source>
        <translation>Automatické nasvícení</translation>
    </message>
    <message>
        <source>Automatic Gain</source>
        <translation>Automatické zesílení</translation>
    </message>
    <message>
        <source>Automatic Iris</source>
        <translation>Automatické stínítko (clona)</translation>
    </message>
    <message>
        <source>Automatic Tilt</source>
        <translation>Automatické naklonění</translation>
    </message>
    <message>
        <source>Automatic Roll</source>
        <translation>Automatické točení</translation>
    </message>
    <message>
        <source>Automatic Zoom</source>
        <translation>Automatické zvětšení</translation>
    </message>
    <message>
        <source>Video Quality</source>
        <translation>Jakost obrazu</translation>
    </message>
    <message>
        <source>Focus:</source>
        <translation>Zaostření:</translation>
    </message>
    <message>
        <source>Gamma:</source>
        <translation>Gama:</translation>
    </message>
    <message>
        <source>Restore Camera Settings...</source>
        <translation>Obnovit nastavení kamery...</translation>
    </message>
    <message>
        <source>Backlight Compensation:</source>
        <translation>Vyrovnání osvětlení zezadu:</translation>
    </message>
    <message>
        <source>Contrast:</source>
        <translation>Kontrast:</translation>
    </message>
    <message>
        <source>Automatic Color Enable</source>
        <translation>Automatické povolení barvy</translation>
    </message>
    <message>
        <source>Abort Reset</source>
        <translation>Zrušit nastavení na výchozí hodnoty</translation>
    </message>
    <message>
        <source>Automatic White Balance</source>
        <translation>Automatické vyvážení bílé</translation>
    </message>
    <message>
        <source>qStopMotion Camera Controller</source>
        <translation>Řízení kamery pro qStopMotion</translation>
    </message>
    <message>
        <source>&amp;Reset to Default</source>
        <translation>&amp;Nastavit znovu na výchozí</translation>
    </message>
    <message>
        <source>Exposure:</source>
        <translation>Osvětlení:</translation>
    </message>
    <message>
        <source>Saturation:</source>
        <translation>Sytost:</translation>
    </message>
    <message>
        <source>White Balance:</source>
        <translation>Vyvážení bílé:</translation>
    </message>
    <message>
        <source>Sharpness:</source>
        <translation>Ostrost:</translation>
    </message>
    <message>
        <source>Automatic Contrast</source>
        <translation>Automatický kontrast</translation>
    </message>
    <message>
        <source>Automatic Sharpness</source>
        <translation>Automatická ostrost</translation>
    </message>
    <message>
        <source>Reset Camera Settings...</source>
        <translation>Nastavit kameru na výchozí hodnoty...</translation>
    </message>
    <message>
        <source>Automatic Brightness</source>
        <translation>Automatický jas</translation>
    </message>
    <message>
        <source>Automatic Gamma</source>
        <translation>Automatická gama</translation>
    </message>
    <message>
        <source>Automatic Focus</source>
        <translation>Automatická ostrost obrazu</translation>
    </message>
    <message>
        <source>Automatic Saturation</source>
        <translation>Automatická sytost</translation>
    </message>
    <message>
        <source>Brightness:</source>
        <translation>Jas:</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>ControllerWidget</name>
    <message>
        <source>Below you can set which features of the camera should be used in the camera control dialog.</source>
        <translation>Níže můžete vybrat, které funkce kamery se mají použít v dialogu pro ovládání kamery.</translation>
    </message>
    <message>
        <source>Image quality controls</source>
        <translation>Ovládání jakosti obrázku</translation>
    </message>
    <message>
        <source>Brightness control</source>
        <translation>Ovládání jasu</translation>
    </message>
    <message>
        <source>Contrast control</source>
        <translation>Ovládání kontrastu</translation>
    </message>
    <message>
        <source>Saturation control</source>
        <translation>Ovládání sytosti</translation>
    </message>
    <message>
        <source>Hue control</source>
        <translation>Ovládání barevného tónu</translation>
    </message>
    <message>
        <source>Gamma control</source>
        <translation>Ovládání gamy</translation>
    </message>
    <message>
        <source>Sharpness control</source>
        <translation>Ovládání ostrosti</translation>
    </message>
    <message>
        <source>Backlight compensation control</source>
        <translation>Ovládání vyrovnání osvětlení zezadu</translation>
    </message>
    <message>
        <source>White balance control</source>
        <translation>Ovládání vyvážení bílé</translation>
    </message>
    <message>
        <source>Gain control</source>
        <translation>Ovládání zesílení</translation>
    </message>
    <message>
        <source>Color enable control</source>
        <translation>Ovládání povolení barvy</translation>
    </message>
    <message>
        <source>Camera controls</source>
        <translation>Ovládání kamery</translation>
    </message>
    <message>
        <source>Exposure control</source>
        <translation>Ovládání osvitu</translation>
    </message>
    <message>
        <source>Zoom control</source>
        <translation>Ovládání přiblížení a oddálení</translation>
    </message>
    <message>
        <source>Focus control</source>
        <translation>Ovládání ostření</translation>
    </message>
    <message>
        <source>Pan control</source>
        <translation>Ovládání smyku (pohyb kamery)</translation>
    </message>
    <message>
        <source>Tilt control</source>
        <translation>Ovládání naklonění</translation>
    </message>
    <message>
        <source>Iris control</source>
        <translation>Ovládání duhovky</translation>
    </message>
    <message>
        <source>Roll control</source>
        <translation>Ovládání točení</translation>
    </message>
</context>
<context>
    <name>DescriptionDialog</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>The character &apos;|&apos; is not allowed in the project description.</source>
        <translation>Znak &apos;|&apos; není v popisu projektu dovolen.</translation>
    </message>
    <message>
        <source>&amp;Take Description:</source>
        <translation>Popis &amp;záběru:</translation>
    </message>
    <message>
        <source>Project Description</source>
        <translation>Popis projektu</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Take Description</source>
        <translation>Popis záběru</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>The character &apos;|&apos; is not allowed in the take description.</source>
        <translation>Znak &apos;|&apos; není v popisu záběru (nahrávky) dovolen.</translation>
    </message>
    <message>
        <source>The character &apos;|&apos; is not allowed in the scene description.</source>
        <translation>Znak &apos;|&apos; není v popisu výjevu dovolen.</translation>
    </message>
    <message>
        <source>Scene Description</source>
        <translation>Popis výjevu</translation>
    </message>
    <message>
        <source>&amp;Project Description:</source>
        <translation>&amp;Popis projektu:</translation>
    </message>
    <message>
        <source>&amp;Scene Description:</source>
        <translation>Popis &amp;výjevu:</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>DomainFacade</name>
    <message>
        <source>Can&apos;t copy image to temp directory!</source>
        <translation>Obrázek nelze kopírovat do adresáře s dočasnými soubory!</translation>
    </message>
    <message>
        <source>Can&apos;t open history file to write entry!</source>
        <translation>Soubor s historií, aby mohl být přidán nový záznam, nelze otevřít!</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Važné</translation>
    </message>
    <message>
        <source>Can&apos;t open history file to recover project!</source>
        <translation>Soubor s historií, aby mohl být projekt obnoven, nelze otevřít!</translation>
    </message>
</context>
<context>
    <name>ExportWidget</name>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>AVI</source>
        <translation>AVI</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Below you can set which program should be used for encoding the currently active project to a video file.</source>
        <translation>Níže můžete vybrat, který program se má použít na zakódování nyní činného projektu do souboru s obrazovým záznamem.</translation>
    </message>
    <message>
        <source>Video Size:</source>
        <translation>Velikost obrazu:</translation>
    </message>
    <message>
        <source>Video Format:</source>
        <translation>Obrazový formát:</translation>
    </message>
    <message>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Snímků za sekundu&lt;/h4&gt; &lt;p&gt;Změnou hodnoty v tomto voliči můžete nastavit rychlost, se kterou se animace odvíjí v &lt;b&gt;zobrazení snímků&lt;/b&gt;.&lt;/p&gt; &lt;p&gt;Pro spuštění animace stiskněte tlačítko &lt;b&gt;Přehrát&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Frame Size</source>
        <translation>Velikost okénka filmu</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Below you can set which program should be used for encoding a new project to a video file.</source>
        <translation>Níže můžete vybrat, který program se má použít na zakódování nového projektu do souboru s obrazovým záznamem.</translation>
    </message>
    <message>
        <source>Do you want to be asked for an output file everytime you choose to export?</source>
        <translation>Chcete být dotazován na název výstupního souboru pokaždé, když si vyberete vyvedení projektu do souboru?</translation>
    </message>
    <message>
        <source>ffmpeg</source>
        <translation>ffmpeg</translation>
    </message>
    <message>
        <source>Frames per Second:</source>
        <translation>Snímků za sekundu:</translation>
    </message>
    <message>
        <source>Choose output file</source>
        <translation>Vybrat výstupní soubor</translation>
    </message>
    <message>
        <source>Encoder settings</source>
        <translation>Nastavení kodéru</translation>
    </message>
    <message>
        <source>Encoder Application:</source>
        <translation>Program kodéru:</translation>
    </message>
    <message>
        <source>SVGA (800x600)</source>
        <translation>SVGA (800 x 600)</translation>
    </message>
    <message>
        <source>Full HD (1900x1080)</source>
        <translation>Full HD (1900 x 1080)</translation>
    </message>
    <message>
        <source>HD Ready (1280x720)</source>
        <translation>HD Ready (1280 x 720)</translation>
    </message>
    <message>
        <source>Output file settings</source>
        <translation>Nastavení výstupního souboru</translation>
    </message>
    <message>
        <source>VGA (640x480)</source>
        <translation>VGA (640 x 480)</translation>
    </message>
    <message>
        <source>PAL D (704x576)</source>
        <translation>PAL D (704 x 576)</translation>
    </message>
    <message>
        <source>Set default output file:</source>
        <translation>Vyberte výstupní název výstupního souboru:</translation>
    </message>
    <message>
        <source>QVGA (320x240)</source>
        <translation>QVGA (320 x 240)</translation>
    </message>
    <message>
        <source>libav</source>
        <translation>libav</translation>
    </message>
</context>
<context>
    <name>Exposure</name>
    <message>
        <source>Can&apos;t copy the image to the project directory!</source>
        <translation>Obrázek nelze kopírovat do adresáře s projektem!</translation>
    </message>
    <message>
        <source>Can&apos;t remove the image in the temporary directory!</source>
        <translation>Obrázek nelze v adresáři s dočasnými soubory smazat!</translation>
    </message>
    <message>
        <source>Can&apos;t copy the image to the temporary directory!</source>
        <translation>Obrázek nelze kopírovat do adresáře s dočasnými soubory!</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Važné</translation>
    </message>
    <message>
        <source>Can&apos;t remove the image from the project directory!</source>
        <translation>Obrázek nelze v adresáři s projektem smazat!</translation>
    </message>
    <message>
        <source>Can&apos;t save the image in the new file format to the temporary directory!</source>
        <translation>Obrázek nelze v novém formátu uložit do adresáře s dočasnými soubory!</translation>
    </message>
</context>
<context>
    <name>ExternalCommandDialog</name>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Result</source>
        <translation>Výsledek</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Poslat</translation>
    </message>
    <message>
        <source>Output from external command</source>
        <translation>Výstup z vnějšího příkazu</translation>
    </message>
    <message>
        <source>Failed!</source>
        <translation>Nepodařilo se!</translation>
    </message>
    <message>
        <source>Successful!</source>
        <translation>Podařilo se!</translation>
    </message>
    <message>
        <source>Input to program:</source>
        <translation>Vstup do programu:</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>GeneralDialog</name>
    <message>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Video Export</source>
        <translation>Vyvedení obrazu</translation>
    </message>
    <message>
        <source>Image Import</source>
        <translation>Zavedení obrázku</translation>
    </message>
    <message>
        <source>Image Transformation</source>
        <translation>Proměna obrázku</translation>
    </message>
    <message>
        <source>qStopMotion Preferences</source>
        <translation>Nastavení qStopMotion</translation>
    </message>
    <message>
        <source>New Project Values</source>
        <translation>Nastavení nového projektu</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Grabber</source>
        <translation>Zachytávač obrazu</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Camera Controller</source>
        <translation>Ovládací spínač kamery</translation>
    </message>
</context>
<context>
    <name>GeneralWidget</name>
    <message>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <source>Capture Button Functionality</source>
        <translation>Funkce zachytávacího tlačítka</translation>
    </message>
    <message>
        <source>Vertical Lines</source>
        <translation>Počet svislých čar</translation>
    </message>
    <message>
        <source>Grid Color:</source>
        <translation>Barva čar mřížky:</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Append new frame at the end of the take</source>
        <translation>Vložení nového okénka (snímku filmu) na konec záběru</translation>
    </message>
    <message>
        <source>Insert new frame after selected frame</source>
        <translation>Vložení nového okénka za vybrané okénko (snímek filmu)</translation>
    </message>
    <message>
        <source>Grid Functionality</source>
        <translation>Čáry mřížky</translation>
    </message>
    <message>
        <source>Horizontal Lines</source>
        <translation>Počet vodorovných čar</translation>
    </message>
    <message>
        <source>Insert new frame bevor selected frame</source>
        <translation>Vložení nového okénka před vybrané okénko (snímek filmu)</translation>
    </message>
    <message>
        <source>Signal Functionality</source>
        <translation>Funkce signálu</translation>
    </message>
    <message>
        <source>Take Picture Signal</source>
        <translation>Signál k udělání záběru</translation>
    </message>
</context>
<context>
    <name>GrabberWidget</name>
    <message>
        <source>Grabber Functionality</source>
        <translation>Funkce digitalizace obrazu</translation>
    </message>
    <message>
        <source>Microsoft Media Foundation Source</source>
        <translation>Zdroj Microsoft Media Foundation</translation>
    </message>
    <message>
        <source>Video 4 Linux 2 Source</source>
        <translation>Zdroj Video pro Linux 2</translation>
    </message>
    <message>
        <source>Pease restart qStopMotion to activate the changings!</source>
        <translation>Pro zapnutí změn spusťte, prosím, qStopMotion znovu!</translation>
    </message>
    <message>
        <source>GStreamer Video 4 Linux 2 Source</source>
        <translation type="vanished">Zdroj GStreamer Video pro Linux 2</translation>
    </message>
    <message>
        <source>GStreamer DV1394 Source</source>
        <translation type="vanished">Zdroj GStreamer DV1394</translation>
    </message>
    <message>
        <source>Gphoto2 Source (Experimental)</source>
        <translation>Zdroj Gphoto2 (pokusné)</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>GStreamer Video Test Source</source>
        <translation type="vanished">Zdroj zkoušky obrazu GStreamer</translation>
    </message>
    <message>
        <source>Below you can select which image grabber should be used for grabbing images from the camera. If available the controller can be used to control focus, zoom and other functionality.</source>
        <translation>Zde můžete vybrat, který zachytávač (digitalizace obrazu) se má použít, pro zachytávání (nahrávání) obrázků z kamery. Ovládacího spínače lze použít na řízení ostření obrazu, přibližování a oddalování a jiné funkce, když je dostupný.</translation>
    </message>
    <message>
        <source>Camera Controller (Experimental)</source>
        <translation>Ovládací spínač kamery (pokusné)</translation>
    </message>
</context>
<context>
    <name>GstreamerDv1394Grabber</name>
    <message>
        <source>Device %1</source>
        <translation type="vanished">Zařízení %1</translation>
    </message>
</context>
<context>
    <name>GstreamerV4L2Grabber</name>
    <message>
        <source>Device %1</source>
        <translation type="vanished">Zařízení %1</translation>
    </message>
</context>
<context>
    <name>GstreamerVideoTestGrabber</name>
    <message>
        <source>Video test device</source>
        <translation type="vanished">Zařízení na zkoušku obrazu</translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Na začátek</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>&amp;Backward</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>qStopMotion Help Browser</source>
        <translation>Prohlížeč nápovědy ke qStopMotion</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vpřed</translation>
    </message>
</context>
<context>
    <name>ImageGrabberFacade</name>
    <message>
        <source>Check image grabber</source>
        <translation>Přezkoušet zachytávač obrázků</translation>
    </message>
    <message>
        <source>Image grabber initialization failed. This may happen 
if you try to grab from an invalid device. Please
select another device on the recording tool tab.</source>
        <translation>Spuštění zachytávače obrázků (digitalizace obrazu) se nezdařila.
To se může přihodit, když se chce nahrávat rušeného zařízení.
Vyberte, prosím, na kartě pro nahrávání jiné zařízení.</translation>
    </message>
    <message>
        <source>No usable video image source found. Please
connect on video device on the computer.</source>
        <translation>Nebyl nalezen žádný použitelný zdroj obrázků pro
obrazový záznam. Připojte, prosím,
zařízení pro práci s obrazem k počítači.</translation>
    </message>
    <message>
        <source>Check image sources</source>
        <translation>Přezkoušet zdroj obrázků</translation>
    </message>
</context>
<context>
    <name>ImportWidget</name>
    <message>
        <source>0.1</source>
        <translation type="vanished">0,1</translation>
    </message>
    <message>
        <source>5.0</source>
        <translation type="vanished">5,0</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Max</source>
        <translation>Největší</translation>
    </message>
    <message>
        <source>Min</source>
        <translation>Nejmenší</translation>
    </message>
    <message>
        <source>JPEG</source>
        <translation>JPEG</translation>
    </message>
    <message>
        <source>TIFF</source>
        <translation>TIFF</translation>
    </message>
    <message>
        <source>Default Grabber Size</source>
        <translation>Výchozí velikost zdroje obrázků</translation>
    </message>
    <message>
        <source>Live view settings</source>
        <translation>Nastavení živého pohledu</translation>
    </message>
    <message>
        <source>Image Size:</source>
        <translation>Velikost obrázku:</translation>
    </message>
    <message>
        <source>Below you can set which image sources should be used for importing images to a new project.</source>
        <translation>Níže můžete vybrat, které zdroje obrázků se mají používat pro zavádění obrázků do nového projektu.</translation>
    </message>
    <message>
        <source>Frames per second:</source>
        <translation>Snímků za sekundu:</translation>
    </message>
    <message>
        <source>Image Quality:</source>
        <translation>Jakost obrázku:</translation>
    </message>
    <message>
        <source>SVGA (800x600)</source>
        <translation>SVGA (800 x 600)</translation>
    </message>
    <message>
        <source>Full HD (1900x1080)</source>
        <translation>Full HD (1900 x 1080)</translation>
    </message>
    <message>
        <source>Below you can set which image sources should be used for importing images to the currently active project.</source>
        <translation>Níže můžete vybrat, které zdroje obrázků se mají používat pro zavádění obrázků do nynějšího projektu.</translation>
    </message>
    <message>
        <source>HD Ready (1280x720)</source>
        <translation>HD Ready (1280 x 720)</translation>
    </message>
    <message>
        <source>Image Format:</source>
        <translation>Obrázkový formát:</translation>
    </message>
    <message>
        <source>VGA (640x480)</source>
        <translation>VGA (640 x 480)</translation>
    </message>
    <message>
        <source>PAL D (704x576)</source>
        <translation>PAL D (704 x 576)</translation>
    </message>
    <message>
        <source>Image import settings</source>
        <translation>Nastavení zavedení obrázku</translation>
    </message>
    <message>
        <source>QVGA (320x240)</source>
        <translation>QVGA (320 x 240)</translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nový&lt;/h4&gt; &lt;p&gt;Vytvoří &lt;em&gt;nový&lt;/em&gt; project.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Re&amp;do</source>
        <translation>&amp;Znovu</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Obraz</translation>
    </message>
    <message>
        <source>MP4 Videos (*.mp4)</source>
        <translation>Filmy MP4 (*.mp4)</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>Neuložené změny</translation>
    </message>
    <message>
        <source>The project directory must not contain more than one project file.</source>
        <translation>V každém adresáři s projektem smí být jen jeden soubor s projektem.</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>Co je &amp;toto</translation>
    </message>
    <message>
        <source>AVI Videos (*.avi)</source>
        <translation>Filmy AVI (*.avi)</translation>
    </message>
    <message>
        <source>&amp;Camera Controller</source>
        <translation>Ovládací spínač &amp;kamery</translation>
    </message>
    <message>
        <source>&amp;Undo stack</source>
        <translation>Seznam kroků &amp;zpět</translation>
    </message>
    <message>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation>Musíte vybrat nějaký zachytávač obrázků,
který se bude používat. Toto se dá nastavit
nabídce pro nastavení.</translation>
    </message>
    <message>
        <source>Preferences of qStopMotion</source>
        <translation>Nastavení pro qStopMotion</translation>
    </message>
    <message>
        <source>Take ID: </source>
        <translation>ID záběru: </translation>
    </message>
    <message>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Zpět&lt;/h4&gt; &lt;p&gt;Vrátí jednu nebo více operací zpět.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Uložit projekt</translation>
    </message>
    <message>
        <source>&lt;h4&gt;TimeLine&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Časová přímka&lt;/h4&gt; &lt;p&gt;V této oblasti vidíte snímky (obrázky) a výjevy animace. Těmito posunujete sem a tam, a tím stavíte animaci.&lt;/p&gt;&lt;p&gt;&lt;b&gt;Klávesami šipek&lt;/b&gt; nebo &lt;b&gt;x&lt;/b&gt; a &lt;b&gt;z&lt;/b&gt; se pohybujete mezi snímky (obrázky) vpřed (další) a zpět (předchozí)&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="vanished">&amp;O programu</translation>
    </message>
    <message>
        <source>Remove Scene</source>
        <translation>Smazat výjev</translation>
    </message>
    <message>
        <source>Open project</source>
        <translation>Otevřít projekt</translation>
    </message>
    <message>
        <source>qStopMotion - New Animation Project</source>
        <translation>qStopMotion - Nový projekt animace</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the qStopMotion manual&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nápověda&lt;/h4&gt; &lt;p&gt;Tímto tlačítkem se vyvolá příručka qStopMotion&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Take ID&lt;/h4&gt;&lt;p&gt;This area displays the id of the currently selected take&lt;/p&gt;</source>
        <translation>&lt;h4&gt;ID záběru&lt;/h4&gt;&lt;p&gt;Toto pole ukazuje ID nyní vybraného záběru&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Insert Scene</source>
        <translation>Vložit výjev</translation>
    </message>
    <message>
        <source>Properties of the animation project</source>
        <translation>Vlastnosti projektu animace</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Obraz&lt;/h4&gt; &lt;p&gt;Vyvede nynější projekt jako &lt;em&gt;soubor s obrazem&lt;/em&gt;.&lt;/p&gt;Při tomto budete vedeni průvodcem.</translation>
    </message>
    <message>
        <source>Existing Images</source>
        <translation>Stávající obrázky</translation>
    </message>
    <message>
        <source>Scene ID: </source>
        <translation>ID výjevu: </translation>
    </message>
    <message>
        <source>Insert Frames</source>
        <translation>Vložit obrázky</translation>
    </message>
    <message>
        <source>Exposure ID: </source>
        <translation>ID osvitu snímku: </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>No encoder selected for the video export.
This can be set in the properties dialog of the project.
Export to video will not be possible until you
have set an encoder to use!</source>
        <translation>Pro vyvedení obrazového záznamu není vybrán
žádný kodér. Toto můžete změnit v dialogu pro
nastaveníi projektu. vyvedení obrazu bude možné
teprve, až vyberete nějaký kodér. Chcete to udělat nyní?</translation>
    </message>
    <message>
        <source>Exporting ...</source>
        <translation>Vyvádí se...</translation>
    </message>
    <message>
        <source>Cinelerra</source>
        <translation>Cinelerra</translation>
    </message>
    <message>
        <source>Add Frames</source>
        <translation>Přidat obrázky</translation>
    </message>
    <message>
        <source>Choose project file</source>
        <translation>Vyberte soubor s projektem</translation>
    </message>
    <message>
        <source>No video format selected for the video export.
This can be set in the properties dialog of the project.
Export to video will not be possible until you
have set an video format to use!</source>
        <translation>Pro vyvedení obrazového záznamu není vybrán
žádný formát obrazu. Toto můžete změnit v dialogu pro
nastaveníi projektu. vyvedení obrazu bude možné
teprve, až vyberete nějaký kodér. Chcete to udělat nyní?</translation>
    </message>
    <message>
        <source>The character &apos;|&apos; is not allowed in the project file name and will be removed.</source>
        <translation>Znak &apos;|&apos; není v názvu souboru s projektem dovolen a bude odstraněn.</translation>
    </message>
    <message>
        <source>Add Scene</source>
        <translation>Přidat výjev</translation>
    </message>
    <message>
        <source>Export to file</source>
        <translation>Vyvést do souboru</translation>
    </message>
    <message>
        <source>qStopMotion - Undo stack</source>
        <translation>qStopMotion - Seznam kroků zpět</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Znovu&lt;/h4&gt; &lt;p&gt;Poslední operace bude obnovena. Můžete to udělat vícekrát.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="vanished">O &amp;Qt</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Zobrazení snímků&lt;/h4&gt;&lt;p&gt; V této oblasti vidíte vybraný snímek (obrázek). Zde se také přehrávají animace, když stisknete tlačítko &lt;b&gt;Přehrát&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a qStopMotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Otevřít&lt;/h4&gt; &lt;p&gt;&lt;em&gt;otevře&lt;/em&gt; soubor s projektem qStopMotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>New project</source>
        <translation>Nový projekt</translation>
    </message>
    <message>
        <source>The Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <source>You have to define an image grabber to use.
This can be set on the recording tool tab.</source>
        <translation>Musíte vybrat nějaký zachytávač obrázků,
který se bude používat. Toto se dá nastavit
na kartě pro nahrávání.</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Uložit &amp;jako</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a qStopMotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Uložit&lt;/h4&gt; &lt;p&gt;Uloží nynější animaci jako soubor s projektem qStopMotion. &lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Exposure ID&lt;/h4&gt;&lt;p&gt;This area displays the id of the currently selected exposure&lt;/p&gt;</source>
        <translation>&lt;h4&gt;ID snímku&lt;/h4&gt;&lt;p&gt;Toto pole ukazuje ID nyní vybraného snímku&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Insert Take</source>
        <translation>Vložit záběr</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Co je to?&lt;/h4&gt; &lt;p&gt;Ukazovátko myši se změní a ukáže nápomocné informace o předmětu, na který bylo klepnuto.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <source>Connecting camera...</source>
        <translation>Vytváří se spojení s kamerou...</translation>
    </message>
    <message>
        <source>Add Take</source>
        <translation>Přidat záběr</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Nahrávání</translation>
    </message>
    <message>
        <source>Take 01</source>
        <translation>Záběr 01</translation>
    </message>
    <message>
        <source>Select image grabber</source>
        <translation>Vyberte zachytávač obrázků</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Vyvést</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Preferences of the application&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;change&lt;/em&gt; the preferences of the application.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nastavení programu&lt;/h4&gt; &lt;p&gt;Tímto se otevře okno, v němž můžete &lt;em&gt;změnit&lt;/em&gt; nastavení programu.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation>Jsou neuložené změny. Chcete je uložit?</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ukončit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;ukončí&lt;/em&gt; program.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Project (*.%1)</source>
        <translation>Projekt (*.%1)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;About Qt&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information about the Qt library.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;O Qt&lt;/h4&gt; &lt;p&gt;Tímto se ukáže malé informační okno, v němž si můžete přečíst všeobecné informace o knihovně Qt.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Remove Frames</source>
        <translation>Odstranit snímky</translation>
    </message>
    <message>
        <source>Remove Take</source>
        <translation>Smazat záběr</translation>
    </message>
    <message>
        <source>Scene 001</source>
        <translation>Výjev 001</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Angličtina</translation>
    </message>
    <message>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;O programu&lt;/h4&gt; &lt;p&gt;Tímto se ukáže malé informační pole, v němž si můžete přečíst všeobecné informace a rovněž jméno vývojáře tohoto vynikajícího kusu programu.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Cinelerra&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;cinelerra-cv&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Cinelerra&lt;/h4&gt; &lt;p&gt;vyvede nynější animaci jako projekt programu &lt;em&gt;cinelerra-cv&lt;/em&gt;.&lt;/p&gt;Při tomto budete vedeni průvodcem.</translation>
    </message>
    <message>
        <source>Ready to rumble ;-)</source>
        <translation>Teď!</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a qStopMotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Uložit jako&lt;/h4&gt;&lt;em&gt;Uloží&lt;/em&gt; nynější animaci jako soubor s projektem qStopMotion.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Save project As</source>
        <translation>Uložit projekt jako</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>No default output file name defined.
Check your settings in the properties dialo of the project!</source>
        <translation>Nestanoven žádný výchozí název pro výstupní soubor.
Prověřte nastavení v dialogu vlastností projektu!</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>The selected encoder is not valid.
Check your settings in the properties dialog of the project!</source>
        <translation type="vanished">Vybraný kodér není platný.
Prověřte nastavení v dialogu vlastností projektu!</translation>
    </message>
    <message>
        <source>&amp;Windows</source>
        <translation>&amp;Okna</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>Co je toto</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Scene ID&lt;/h4&gt;&lt;p&gt;This area displays the id of the currently selected scene&lt;/p&gt;</source>
        <translation>&lt;h4&gt;ID výjevu&lt;/h4&gt;&lt;p&gt;Toto pole ukazuje ID nyní vybraného výjevu&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Export to video file</source>
        <translation>Vyvést do souboru s obrazem</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Project ID&lt;/h4&gt;&lt;p&gt;This area displays the id of the currently active project&lt;/p&gt;</source>
        <translation>&lt;h4&gt;ID projektu&lt;/h4&gt;&lt;p&gt;Toto pole ukazuje ID nyní činného projektu&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Otevřít &amp;nedávný</translation>
    </message>
    <message>
        <source>Project ID: </source>
        <translation>ID projektu: </translation>
    </message>
    <message>
        <source>There are some images in the open project. Do you want to convert the images to the new file format or quality?</source>
        <translation>V otevřeném projektu jsou nějaké obrázky. Chcete tyto obrázky převést do nového souborového formátu nebo do nové jakosti?</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Properties of the project&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;change&lt;/em&gt; properties of the animation project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vlastnosti projektu&lt;/h4&gt; &lt;p&gt;Tímto se otevře okno, v němž můžete &lt;em&gt;změnit&lt;/em&gt; vlastnosti projektu.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation>Angličtina</translation>
    </message>
    <message>
        <source>The selected encoder is not installed on your computer.
Install the encoder or select another one!</source>
        <translation>Vybraný kodér není nainstalován na vašem počítači.
Kodér nainstalujte nebo vyberte jiný!</translation>
    </message>
    <message>
        <source>Online Help</source>
        <translation>Nápověda na internetu</translation>
    </message>
    <message>
        <source>Support Us</source>
        <translation>Podpořte nás</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Online Help&lt;/h4&gt; &lt;p&gt;This button will bring up the browser with the qStopMotion manual in different languages&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Nápověda na internetu&lt;/h4&gt; &lt;p&gt;Tímto tlačítkem se vyvolá prohlížeč s příručkou k qStopMotion v různých jazycích&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Support Us&lt;/h4&gt; &lt;p&gt;This button will bring up the browser with the qStopMotion support us page&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Podpořte nás&lt;/h4&gt; &lt;p&gt;Tímto tlačítkem se vyvolá prohlížeč se stránkou k qStopMotion Podpořte nás&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>PreferencesTool</name>
    <message>
        <source>DOM Parser</source>
        <translation>Syntaktický analyzátor DOM</translation>
    </message>
    <message>
        <source>Can&apos;t copy preferences file to backup file!</source>
        <translation>Soubor s nastavením nelze kopírovat do souboru se zálohou!</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Važné</translation>
    </message>
    <message>
        <source>Can&apos;t remove preferences backup file!</source>
        <translation>Záložní soubor souboru s nastavením nelze smazat!</translation>
    </message>
    <message>
        <source>Couldn&apos;t open XML file:
%1</source>
        <translation>Nepodařilo se otevřít soubor XML:
%1</translation>
    </message>
    <message>
        <source>Parse error at line %1, column %2:
%3
%4</source>
        <translation>Chyba při zpracování na řádku %1, sloupec %2:
%3
%4</translation>
    </message>
</context>
<context>
    <name>ProjectDialog</name>
    <message>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Video Export</source>
        <translation>Vyvedení obrazu</translation>
    </message>
    <message>
        <source>Image Import</source>
        <translation>Zavedení obrázku</translation>
    </message>
    <message>
        <source>Image Transformation</source>
        <translation>Proměna obrázku</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <source>Animation Project Properties</source>
        <translation>Vlastnosti projektu animace</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>ProjectSerializer</name>
    <message>
        <source>Can&apos;t change permissions of the sound directory!</source>
        <translation>Nelze změnit přístupová práva k adresáři se zvuky!</translation>
    </message>
    <message>
        <source>Can&apos;t remove old backup of project file!</source>
        <translation>Starý záložní soubor souboru s projektem nelze smazat!</translation>
    </message>
    <message>
        <source>Can&apos;t create sound directory!</source>
        <translation>Nelze vytvořit adresář se zvuky!</translation>
    </message>
    <message>
        <source>DOM Parser</source>
        <translation>Syntaktický analyzátor DOM</translation>
    </message>
    <message>
        <source>Can&apos;t create project directory!</source>
        <translation>Nelze vytvořit adresář s projektem!</translation>
    </message>
    <message>
        <source>Can&apos;t change permissions of the image directory!</source>
        <translation>Nelze změnit přístupová práva k adresáři s obrázky!</translation>
    </message>
    <message>
        <source>Can&apos;t copy the project file to backup!</source>
        <translation>Soubor s projektem nelze kopírovat do souboru se zálohou!</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Važné</translation>
    </message>
    <message>
        <source>Can&apos;t create image directory!</source>
        <translation>Nelze vytvořit adresář s obrázky!</translation>
    </message>
    <message>
        <source>Can&apos;t change permissions of the project directory!</source>
        <translation>Nelze změnit přístupová práva k adresáři s projektem!</translation>
    </message>
    <message>
        <source>Couldn&apos;t open XML file:
%1</source>
        <translation>Nepodařilo se otevřít soubor XML:
%1</translation>
    </message>
    <message>
        <source>Parse error at line %1, column %2:
%3
%4</source>
        <translation>Chyba při zpracování na řádku %1, sloupec %2:
%3
%4</translation>
    </message>
    <message>
        <source>Can&apos;t remove the old project file!</source>
        <translation>Starý soubor s projektem nelze smazat!</translation>
    </message>
</context>
<context>
    <name>ProjectTab</name>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Takes</source>
        <translation>Záběry</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Append new Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to create a new &lt;em&gt;scene&lt;/em&gt; and &lt;em&gt;append&lt;/em&gt; it at the end of the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Připojení nového výjevu (Ctrl+E)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro vytvoření nového &lt;em&gt;výjevu&lt;/em&gt; a pro &lt;em&gt;připojení&lt;/em&gt; animace na konec.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Take (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected &lt;em&gt;take&lt;/em&gt; from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Smazání záběru (Shift+Delete)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro &lt;em&gt;smazání&lt;/em&gt; vybraného &lt;em&gt;záběru&lt;/em&gt; z animace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>The active frame is corrupt</source>
        <translation>Vybraný snímek (obrázek) je poškozen</translation>
    </message>
    <message>
        <source>No take selected. Please select a take in the project tree.</source>
        <translation>Nevybrán žádný záběr. Vyberte, prosím, nějaký záběr v projektovém stromu.</translation>
    </message>
    <message>
        <source>You do not have Gimp installed on your system</source>
        <translation>GIMP není nainstalován v systému</translation>
    </message>
    <message>
        <source>Insert Frames</source>
        <translation>Vložit snímky</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Snímky</translation>
    </message>
    <message>
        <source>Add Frames</source>
        <translation>Přidat snímky</translation>
    </message>
    <message>
        <source>Choose frames to add</source>
        <translation>Vyberte snímky k přidání</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Výjevy</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected &lt;em&gt;scene&lt;/em&gt; from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Smazání výjevu (Shift+Delete)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro &lt;em&gt;smazání&lt;/em&gt; vybraného &lt;em&gt;výjevu&lt;/em&gt; z animace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Failed to start Gimp!</source>
        <translation>Nepodařilo se spustit GIMP!</translation>
    </message>
    <message>
        <source>There is no active frame to open</source>
        <translation>Není vybrán žádný snímek (obrázek) k otevření</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Launch Photo Editor&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in the photo editor&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on the photo editor&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Spuštění programu na úpravy obrázků&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro otevření programu na upravování obrázků&lt;/p&gt; &lt;p&gt;Také je možné, přetáhnout snímky (obrázky) z pruhu se snímky (časová přímka) do otevřeného programu na úpravy obrázků.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Frame (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected &lt;em&gt;frame&lt;/em&gt; from the take.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Smazání snímku (Delete)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro &lt;em&gt;smazání&lt;/em&gt; vybraného &lt;em&gt;snímku&lt;/em&gt; ze záběru.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Append Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;append frames&lt;/em&gt; at the end of the take.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Připojení snímků (Ctrl+F)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro &lt;em&gt;připojení snímků&lt;/em&gt; na konec záběru.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Insert Take</source>
        <translation>Vložit záběr</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Insert new Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to create a new &lt;em&gt;scene&lt;/em&gt; and &lt;em&gt;insert&lt;/em&gt; it bevor the selected scene.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vložení nového výjevu (Ctrl+E)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro vytvoření nového &lt;em&gt;výjevu&lt;/em&gt; a jeho &lt;em&gt;vložení&lt;/em&gt; před vybraný výjev.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Add Take</source>
        <translation>Přidat záběr</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Insert Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;insert frames&lt;/em&gt; bevor the selected frame.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vložení snímků (Ctrl+F)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro &lt;em&gt;vložení snímků&lt;/em&gt; před vybraný snímek.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Take 00</source>
        <translation>Záběr 00</translation>
    </message>
    <message>
        <source>No scene selected. Please select a scene in the project tree.</source>
        <translation>Nevybrán žádný výjev. Vyberte, prosím, nějaký výjev v projektovém stromu.</translation>
    </message>
    <message>
        <source>Scene 000</source>
        <translation>Výjev 000</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Append new Take (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to create a new &lt;em&gt;take&lt;/em&gt; and &lt;em&gt;append&lt;/em&gt; it to the end of the scene.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Připojení nového záběru (Ctrl+E)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro vytvoření nového &lt;em&gt;záběru&lt;/em&gt; a pro jeho &lt;em&gt;připojení&lt;/em&gt; na konec výjevu.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Insert new Take (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to create a new &lt;em&gt;take&lt;/em&gt; and &lt;em&gt;insert&lt;/em&gt; it bevor the selected take.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Vložení nového záběru (Ctrl+E)&lt;/h4&gt; &lt;p&gt;Klepněte na toto tlačítko pro vytvoření nového &lt;em&gt;záběru&lt;/em&gt; a jeho &lt;em&gt;vložení&lt;/em&gt; před vybraný záběr.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Project Tree</source>
        <translation>Projektový strom</translation>
    </message>
</context>
<context>
    <name>ProjectWidget</name>
    <message>
        <source>Mix</source>
        <translation>Směs</translation>
    </message>
    <message>
        <source>Diff</source>
        <translation>Rozdíly</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation type="vanished">Přehrávání</translation>
    </message>
    <message>
        <source>Video 4 Linux (USB WebCam)</source>
        <translation type="vanished">Video 4 Linux (USB WebCam)</translation>
    </message>
    <message>
        <source>Number of images:</source>
        <translation>Počet obrázků:</translation>
    </message>
    <message>
        <source>Single frame capture</source>
        <translation>Zachytávání jednotlivých obrázků</translation>
    </message>
    <message>
        <source>Test Source</source>
        <translation type="vanished">Zdroj zkoušky</translation>
    </message>
    <message>
        <source>IEEE 1394 (FireWire DigiCam)</source>
        <translation type="vanished">IEEE 1394 (FireWire DigiCam)</translation>
    </message>
    <message>
        <source>gphoto (USB Compact Camera)</source>
        <translation>gphoto (Malá kamera USB)</translation>
    </message>
    <message>
        <source>Image grabber settings</source>
        <translation>Nastavení zachytávače (zdroje) obrázků</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Zachytávání</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Nahrávání</translation>
    </message>
    <message>
        <source>Media Foundation</source>
        <translation>Mediální podklad</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation type="vanished">&lt;h4&gt;Počet obrázků&lt;/h4&gt; &lt;p&gt;Tímto posuvníkem (změnou hodnoty) můžete nastavit, kolik předcházejících obrázků v animaci se má zařadit v obrazu kamery. Nebo, pokud jste v režimu přehrávání: Kolik obrázků bude přehráno. &lt;/p&gt; &lt;p&gt;Tím (míšením předchozího obrázku(ů) do kamery) lépe uvidíte, jak je následující obrázek ve vztahu k předcházejícím obrázkům. To umožňuje stejnoměrný (hladší) průběh pohybu!&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Video 4 Linux 2 (USB WebCam)</source>
        <translation>Video 4 Linux (USB WebCam)</translation>
    </message>
    <message>
        <source>Time-lapse capture</source>
        <translation>Časosběrné zachytávání</translation>
    </message>
    <message>
        <source>Time-lapse</source>
        <translation>Časosběr</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Jednotka:</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundy</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuty</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Days</source>
        <translation>Dny</translation>
    </message>
    <message>
        <source>Beep</source>
        <translation>Pípnutí</translation>
    </message>
    <message>
        <source>seconds before picture:</source>
        <translation>sekund před záběrem:</translation>
    </message>
    <message>
        <source>Seconds between pictures</source>
        <translation>Sekund mezi záběry</translation>
    </message>
    <message>
        <source>Minutes between pictures</source>
        <translation>Minut mezi záběry</translation>
    </message>
    <message>
        <source>Hours between pictures</source>
        <translation>Hodin mezi záběry</translation>
    </message>
    <message>
        <source>Days between pictures</source>
        <translation>Dnů mezi záběry</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera.&lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Počet obrázků&lt;/h4&gt; &lt;p&gt;Tímto posuvníkem (změnou hodnoty) můžete nastavit, kolik předcházejících obrázků v animaci se má zařadit v obrazu kamery.&lt;/p&gt; &lt;p&gt;Tím (míšením předchozího obrázku(ů) do kamery) lépe uvidíte, jak je následující obrázek ve vztahu k předcházejícím obrázkům. To umožňuje stejnoměrný (hladší) průběh pohybu!&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>Create directory</source>
        <translation>Vytvořit adresář</translation>
    </message>
    <message>
        <source>qStopMotion - Recovered Project</source>
        <translation>qStopMotion - Obnovený projekt</translation>
    </message>
    <message>
        <source>You do not have the necessary permissions to run qStopMotion.
You need permission to create the .qstopmotion directory in your home directory.</source>
        <translation>Nemáte potřebná oprávnění pro provozování qStopMotion.
tato oprávnění potřebujete k vytvoření adresáře .qstopmotion ve vašem domovském adresáři.</translation>
    </message>
    <message>
        <source>Something caused qStopmotion to exit abnormally
last time it was run. Do you want to recover?</source>
        <translation>Vypadá to, že qStopmotion nebyl při posledním používání správně
ukončen. Chcete obnovit poslední sezení?</translation>
    </message>
    <message>
        <source>You do not have the necessary permissions to run qStopMotion.
You need permission to read, write and execute on the .qstopmotion directory.</source>
        <translation>Nemáte potřebná oprávnění pro provozování qStopMotion.
Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmotion.</translation>
    </message>
    <message>
        <source>Recovery</source>
        <translation>Obnovení</translation>
    </message>
    <message>
        <source>Check Permissions</source>
        <translation>Prověřit přístupová práva</translation>
    </message>
</context>
<context>
    <name>RecordingTab</name>
    <message>
        <source>Mix</source>
        <translation>Směs</translation>
    </message>
    <message>
        <source>Diff</source>
        <translation>Rozdíly</translation>
    </message>
    <message>
        <source>Not Supported</source>
        <translation>Nepodporováno</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation type="vanished">Přehrávání</translation>
    </message>
    <message>
        <source>No take selected. Please select a take on the project tab.</source>
        <translation>Nevybrán žádný záběr. Vyberte, prosím, záběr na kartě projektu.</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Rozlišení:</translation>
    </message>
    <message>
        <source>Number of images:</source>
        <translation>Počet obrázků:</translation>
    </message>
    <message>
        <source>Single frame capture</source>
        <translation>Zachytávání jednotlivých obrázků</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Video Source:</source>
        <translation>Zdroj obrazu:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Zachytávání</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Zapnou/Vypnout kameru (C)&lt;/h4&gt; &lt;p&gt;Klepnutím na toto tlačítko zapnete/vypnete kameru&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="vanished">Nahrávání</translation>
    </message>
    <message>
        <source>No scene and no take selected. Please select a scene and a take on the project tab.</source>
        <translation>Nevybrán žádný výjev a žádný záběr. Vyberte, prosím, výjev a záběr na kartě projektu.</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Počet obrázků&lt;/h4&gt; &lt;p&gt;Tímto posuvníkem (změnou hodnoty) můžete nastavit, kolik předcházejících obrázků v animaci se má zařadit v obrazu kamery. Nebo, pokud jste v režimu přehrávání: Kolik obrázků bude přehráno. &lt;/p&gt; &lt;p&gt;Tím (míšením předchozího obrázku(ů) do kamery) lépe uvidíte, jak je následující obrázek ve vztahu k předcházejícím obrázkům. To umožňuje stejnoměrný (hladší) průběh pohybu!&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No active project. Please create a new project or open an existing project.</source>
        <translation>Žádný projekt není činný. Vytvořte, prosím, nový projekt nebo otevřete stávající projekt.</translation>
    </message>
    <message>
        <source>Recording mode</source>
        <translation>Režim nahrávání</translation>
    </message>
    <message>
        <source>Time-lapse capture</source>
        <translation>Časosběrné zachytávání</translation>
    </message>
    <message>
        <source>Time-lapse</source>
        <translation>Časosběr</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Jednotka:</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundy</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuty</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hodiny</translation>
    </message>
    <message>
        <source>Days</source>
        <translation>Dny</translation>
    </message>
    <message>
        <source>Beep</source>
        <translation>Pípnutí</translation>
    </message>
    <message>
        <source>seconds before picture:</source>
        <translation>sekund před záběrem:</translation>
    </message>
    <message>
        <source>Seconds between pictures</source>
        <translation>Sekund mezi záběry</translation>
    </message>
    <message>
        <source>Minutes between pictures</source>
        <translation>Minut mezi záběry</translation>
    </message>
    <message>
        <source>Hours between pictures</source>
        <translation>Hodin mezi záběry</translation>
    </message>
    <message>
        <source>Days between pictures</source>
        <translation>Dnů mezi záběry</translation>
    </message>
</context>
<context>
    <name>Scene</name>
    <message>
        <source>Can&apos;t remove sound file!</source>
        <translation>Nelze smazat soubor se zvukem!</translation>
    </message>
    <message>
        <source>Can&apos;t copy sound file!</source>
        <translation>Nelze kopírovat soubor se zvukem!</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Važné</translation>
    </message>
</context>
<context>
    <name>StartDialog</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Create a new Project&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Vytvořit nový projekt&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Open project file&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Otevřít soubor s projektem&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Open last Project&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Otevřít poslední projekt&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>Start a new Project.</source>
        <translation>Začít nový projekt.</translation>
    </message>
    <message>
        <source>Open and continue a existing project.</source>
        <translation>Otevřít a pokračovat ve stávajícím projektu.</translation>
    </message>
    <message>
        <source>Project path: </source>
        <translation>Cesta k projektu:</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
</context>
<context>
    <name>TimeLine</name>
    <message>
        <source>Load images to time line</source>
        <translation>Nahrání obrázků do časové přímky</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Running animation</source>
        <translation>Přehrání animace</translation>
    </message>
    <message>
        <source>&lt;h4&gt;First frame of the take (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;První snímek záběru (J, šipka vlevo)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Last frame of the take (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Poslední snímek záběru (L, šipka vpravo)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Přehrát animaci (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Další snímek (L, šipka vpravo)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Zachytit snímek (mezerník)&lt;/h4&gt; &lt;p&gt;Klepnutím na toto tlačítko můžete zachytit jednotlivé snímky z kamery a přidat je do animace. To lze provést i stisknutím klávesy &lt;b&gt;mezerníku&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Předchozí snímek (J, šipka vlevo)&lt;/h4&gt;</translation>
    </message>
</context>
<context>
    <name>TransformWidget</name>
    <message>
        <source>0%</source>
        <translation type="vanished">0 %</translation>
    </message>
    <message>
        <source>100%</source>
        <translation type="vanished">100 %</translation>
    </message>
    <message>
        <source>Zoom the image</source>
        <translation>Zvětšení obrázku kamery</translation>
    </message>
    <message>
        <source>Clip a part of the image</source>
        <translation>Vystřihnutí části obrázku kamery</translation>
    </message>
    <message>
        <source>Zoom value:</source>
        <translation type="vanished">Hodnota zvětšení:</translation>
    </message>
    <message>
        <source>Scale the whole image</source>
        <translation>Změnit velikost celého obrázku</translation>
    </message>
    <message>
        <source>Below you can set which image transformation should be used for importing images to the currently active project. If you select clip a part of the image set also the adjustment for cliping.</source>
        <translation>Níže můžete vybrat, která proměna obrázku se má použít při zavádění obrázků do nyní činného projektu. Pokud vyberete vystřihnutí části obrázku, musíte také nastavit nastavení vystřihnutí.</translation>
    </message>
    <message>
        <source>Below you can set which image transformation should be used for importing images to a new project. If you select clip a part of the image set also the adjustment for cliping.</source>
        <translation>Níže můžete vybrat, která proměna obrázku se má použít při zavádění obrázků do nového projektu. Pokud vyberete vystřihnutí části obrázku, musíte také nastavit nastavení vystřihnutí.</translation>
    </message>
    <message>
        <source>Zoom settings</source>
        <translation>Nastavení zvětšení</translation>
    </message>
    <message>
        <source>Transformation settings</source>
        <translation>Nastavení proměny obrázku</translation>
    </message>
    <message>
        <source>Zoom value (%):</source>
        <translation>Hodnota zvětšení:</translation>
    </message>
    <message>
        <source>Min</source>
        <translation>Nejmenší</translation>
    </message>
    <message>
        <source>Max</source>
        <translation>Největší</translation>
    </message>
</context>
<context>
    <name>UndoExposureAdd</name>
    <message>
        <source>Add exposure (%1,%2,%3) &apos;%4&apos;</source>
        <translation>Přidat snímek (%1,%2,%3) &apos;%4&apos;</translation>
    </message>
</context>
<context>
    <name>UndoExposureInsert</name>
    <message>
        <source>Insert exposure (%1,%2,%3) &apos;%4&apos;</source>
        <translation>Vložit snímek (%1,%2,%3) &apos;%4&apos;</translation>
    </message>
</context>
<context>
    <name>UndoExposureMove</name>
    <message>
        <source>Move exposure (%1,%2,%3)</source>
        <translation>Posunout snímek (%1,%2,%3)</translation>
    </message>
</context>
<context>
    <name>UndoExposureRemove</name>
    <message>
        <source>Remove exposure (%1,%2,%3)</source>
        <translation>Smazat snímek (%1,%2,%3)</translation>
    </message>
</context>
<context>
    <name>UndoExposureSelect</name>
    <message>
        <source>Select exposure (%1,%2,%3)--&gt;(%4,%5,%6)</source>
        <translation>Vybrat snímek (%1,%2,%3)--&gt;(%4,%5,%6)</translation>
    </message>
</context>
<context>
    <name>UndoProjectNew</name>
    <message>
        <source>New project &apos;%1&apos;</source>
        <translation>Nový projekt &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>UndoProjectOpen</name>
    <message>
        <source>Open project &apos;%1&apos;</source>
        <translation>Otevřít projekt &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>UndoSceneAdd</name>
    <message>
        <source>Add scene (%1) &apos;%2&apos;</source>
        <translation>Přidat výjev (%1) &apos;%2&apos;</translation>
    </message>
</context>
<context>
    <name>UndoSceneInsert</name>
    <message>
        <source>Insert scene (%1) &apos;%2&apos;</source>
        <translation>Vložit výjev (%1) &apos;%2&apos;</translation>
    </message>
</context>
<context>
    <name>UndoSceneMove</name>
    <message>
        <source>Move scene (%1,%2)</source>
        <translation>Posunout výjev (%1,%2)</translation>
    </message>
</context>
<context>
    <name>UndoSceneRemove</name>
    <message>
        <source>Remove scene (%1)</source>
        <translation>Smazat výjev (%1)</translation>
    </message>
</context>
<context>
    <name>UndoSceneSelect</name>
    <message>
        <source>Select scene (%1)--&gt;(%2)</source>
        <translation>Vybrat výjev (%1)--&gt;(%2)</translation>
    </message>
</context>
<context>
    <name>UndoTakeAdd</name>
    <message>
        <source>Add take (%1,%2) &apos;%3&apos;</source>
        <translation>Přidat záběr (%1,%2) &apos;%3&apos;</translation>
    </message>
</context>
<context>
    <name>UndoTakeInsert</name>
    <message>
        <source>Insert take (%1,%2) &apos;%3&apos;</source>
        <translation>Vložit záběr (%1,%2) &apos;%3&apos;</translation>
    </message>
</context>
<context>
    <name>UndoTakeMove</name>
    <message>
        <source>Move take (%1,%2)</source>
        <translation>Posunout záběr (%1,%2)</translation>
    </message>
</context>
<context>
    <name>UndoTakeRemove</name>
    <message>
        <source>Remove take (%1,%2)</source>
        <translation>Smazat záběr (%1,%2)</translation>
    </message>
</context>
<context>
    <name>UndoTakeSelect</name>
    <message>
        <source>Select take (%1,%2)--&gt;(%3,%4)</source>
        <translation>Vybrat záběr (%1,%2)--&gt;(%3,%4)</translation>
    </message>
</context>
</TS>
